@@ -1,6 +1,6 @@
 import sys
 sys.path.append('../')
-from linux.shared_scripts.modules import filechecker, folderchecker, sizechecker
+from linux.shared_scripts.modules import filechecker, folderchecker, sizechecker, linechecker, linetotalchecker
 
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
 def taskchecker():
